using System;
using System.Runtime.InteropServices;
using UnityEngine;

namespace com.dataeye.apptutti.supersdk
{
	public interface SuperLoginCallback{
		void onCancel();
		void onComplete(string accountInfoJson);
		void onError(string reason);
	};
	
	public interface SuperPayCallback{
		//json串，reason为付费结果，payIndex为付费点，failReason为失败原因
		void payResult(string message);
	};

	public class SuperSDK : MonoBehaviour
	{
		public const string version="v2.0" ;
		
		static SuperSDK instance;
		
		public static SuperSDK getInstance()
		{
			if(!instance)
			{
				GameObject go = new GameObject("SuperSDK");
				DontDestroyOnLoad(go);
				instance = go.AddComponent<SuperSDK>();
			}
			return instance;
		}
		
		public void init()
		{
			if (Application.platform == RuntimePlatform.Android)
			{
#if UNITY_ANDROID
				using(AndroidJavaClass unityClass = new AndroidJavaClass("com.unity3d.player.UnityPlayer"))
				{
					using(AndroidJavaObject activity = unityClass.GetStatic<AndroidJavaObject>("currentActivity"))
					{
						using(AndroidJavaObject superSDK = new AndroidJavaClass("com.dataeye.apptutti.supersdk.SuperSDK"))
						{
							superSDK.CallStatic("initForUnity", activity);
						}
					}
				}
#endif
			}
		}
		
		public static void share()
		{
			if (Application.platform == RuntimePlatform.Android)
			{
#if UNITY_ANDROID
				using(AndroidJavaClass unityClass = new AndroidJavaClass("com.unity3d.player.UnityPlayer"))
				{
					using(AndroidJavaObject activity = unityClass.GetStatic<AndroidJavaObject>("currentActivity"))
					{
						using(AndroidJavaObject superSDK = new AndroidJavaClass("com.dataeye.apptutti.supersdk.SuperSDK"))
						{
							superSDK.CallStatic("share", activity);
						}
					}
				}
#endif
			}
		}
		
		public static void pay(int payIndex, string orderId, string callbackObjectName)
		{
			if(Application.platform == RuntimePlatform.Android)
			{
#if UNITY_ANDROID
				using(AndroidJavaClass unityClass = new AndroidJavaClass("com.unity3d.player.UnityPlayer"))
				{
					using(AndroidJavaObject activity = unityClass.GetStatic<AndroidJavaObject>("currentActivity"))
					{
						using(AndroidJavaObject superSDK = new AndroidJavaClass("com.dataeye.apptutti.supersdk.SuperSDK"))
						{
							superSDK.CallStatic("payForUnity", activity, payIndex, orderId, callbackObjectName);
						}
					}
				}
#endif
			}
		}
	

		public static void login(string callbackObjectName)
		{

            if(Application.platform == RuntimePlatform.Android)
			{
#if UNITY_ANDROID
				using(AndroidJavaClass unityClass = new AndroidJavaClass("com.unity3d.player.UnityPlayer"))
				{
					using(AndroidJavaObject activity = unityClass.GetStatic<AndroidJavaObject>("currentActivity"))
					{
						using(AndroidJavaObject superSDK = new AndroidJavaClass("com.dataeye.apptutti.supersdk.SuperSDK"))
						{
							superSDK.CallStatic("loginForUnity", activity, callbackObjectName);
						}
					}
				}
#endif
			}
		}

		public static string getAccountInfo()
		{
			if(Application.platform == RuntimePlatform.Android)
			{
#if UNITY_ANDROID
				using(AndroidJavaObject superSDK = new AndroidJavaClass("com.dataeye.apptutti.supersdk.SuperSDK"))
				{
					string accountInfo = superSDK.CallStatic<string>("getAccountInfoForUnity");
					return accountInfo;
				}
#endif
			}
			return null;
		}
		
		public static void showAd()
		{
			if(Application.platform == RuntimePlatform.Android)
			{
#if UNITY_ANDROID
				using(AndroidJavaClass unityClass = new AndroidJavaClass("com.unity3d.player.UnityPlayer"))
				{
					using(AndroidJavaObject activity = unityClass.GetStatic<AndroidJavaObject>("currentActivity"))
					{
						using(AndroidJavaObject superSDK = new AndroidJavaClass("com.dataeye.apptutti.supersdk.SuperSDK"))
						{
							superSDK.CallStatic("showAd", activity);
						}
					}
				}
#endif
			}
		}
		
		void OnApplicationPause(bool pauseStatus)
		{
			if(Application.platform == RuntimePlatform.Android)
			{
#if UNITY_ANDROID
				if(pauseStatus)
				{
					instance.pause();
				}
				else
				{
					instance.resume();
				}
#endif
			}
		}
		
		void resume()
		{
			using(AndroidJavaClass unityClass = new AndroidJavaClass("com.unity3d.player.UnityPlayer"))
			{
				using(AndroidJavaObject activity = unityClass.GetStatic<AndroidJavaObject>("currentActivity"))
				{
					using(AndroidJavaObject superSDK = new AndroidJavaClass("com.dataeye.apptutti.supersdk.SuperSDK"))
					{
						superSDK.CallStatic("onResume", activity);
					}
				}
			}
		}
		
		void pause()
		{
			using(AndroidJavaClass unityClass = new AndroidJavaClass("com.unity3d.player.UnityPlayer"))
			{
				using(AndroidJavaObject activity = unityClass.GetStatic<AndroidJavaObject>("currentActivity"))
				{
					using(AndroidJavaObject superSDK = new AndroidJavaClass("com.dataeye.apptutti.supersdk.SuperSDK"))
					{
						superSDK.CallStatic("onPause", activity);
					}
				}
			}
		}
	}
}